{% extends "vellum/post_list.html" %}
{% load i18n %}

{% block title %}{{ month|date:"F" }} | {{ month|date:"Y" }} | {{ block.super }}{% endblock %}
{% block description %}{{ object_list|length }} {% trans "posts published during" %} {{ month|date:"F Y" }}{% endblock %}
{% block body_class %}{{ block.super }} monthly{% endblock %}
{% block body_id %}post-archive-{{ month|date:"Ym" }}{% endblock %}
{% block page_title %}{% trans "Month" %}: {{ month|date:"F Y" }}{% endblock %}
