{% ifnotequal post.excerpt.strip post.body_rendered.strip %}
    <p class="continue"><a href="{{ post.get_absolute_url }}" title="Continue reading: {{ post.title }}">Continue reading &raquo;</a></p>
{% endifnotequal %}
