{% load i18n %}
<nav>
    <ul>
        <li><a href="{% url vellum %}">{% trans "Posts" %}</a></li>
        <li><a href="{% url vellum_archives %}">{% trans "Archives" %}</a></li>
        <li><a href="{% url vellum_tag_list %}">{% trans "Tags" %}</a></li>
        <li><a href="{% url vellum_category_list %}">{% trans "Categories" %}</a></li>
    </ul>
</nav>
