{% extends "vellum/base_vellum.html" %}

{% load i18n %}

{% block title %}{% trans "Categories" %} | {{ block.super }}{% endblock %}
{% block description %}{% trans "Post categories" %}{% endblock %}
{% block body_id %}category-list{% endblock %}

{% block content %}
    <h1>{% trans "Categories" %}</h1>

    <ul class="categories">
        {% for category in object_list %}
        <li><a href="{{ category.get_absolute_url }}" title="{% trans "View posts categorized as" %} {{ category|lower }}">{{ category }}</a> ({{ category.post_set.published.count }})</li>
        {% endfor %}
    </ul>
{% endblock %}
