{% extends "vellum/base_vellum.html" %}

{% load i18n taggit_extras %}

{% block title %}{% trans "Tags" %} | {{ block.super }}{% endblock %}
{% block description %}{% trans "Post tags" %}{% endblock %}
{% block body_id %}tag-list{% endblock %}

{% block content %}
    <h1>{% trans "Tag Cloud" %}</h1>
    {% get_tagcloud as tags for 'vellum.post' %}
    <ul class="cloud">
    {% for tag in tags %}
    <li style="font-size: {{ tag.weight|floatformat:0 }}em"><a href="{% url vellum_tag_detail slug=tag.slug  %}" title="{% trans "See" %} {{ tag.num_times }} {% trans "items tagged with" %} {{ tag }}">{{ tag }}</a></li>
    {% endfor %}
    </ul>
{% endblock %}
