{% extends "vellum/post_list.html" %}
{% load i18n %}

{% block title %}{{ category }} | {{ block.super }}{% endblock %}
{% block description %}{% trans "Posts about" %} {{ category }}{% endblock %}
{% block body_class %}{{ block.super }} category{% endblock %}
{% block body_id %}post-category-{{ category }}{% endblock %}
{% block page_notice %}<div class="notice"><p>
    {% if object_list %}
    {% trans "You are currently viewing all posts in the " %}
    {% else %}
    {% trans "No posts are in the " %}
    {% endif %}
    <span class="query">{{ category|lower }}</span> {% trans "category" %}.
</p></div>{% endblock %}
