{% extends "base.html" %}
{% block extrahead %}
<link rel="alternate" type="application/rss+xml" title="{{ BLOG_NAME }} Feed" href="{% url vellum_feed_latest %}">
{% endblock %}
{% block title %}{{ BLOG_NAME }}{% endblock %}
{% block description %}{{ BLOG_DESCRIPTION }}{% endblock %}
{% block body_class %}blog{% endblock %}
