{% load i18n %} 
<section id="comments">
    <h1 class="comments-title">{% trans "Comments" %}</h1>
{% if BLOG_USEDISQUS %}
    {% include 'vellum/includes/disqus.html' %}
{% else %}
    {% load comments %} 
    {% get_comment_list for object as comment_list %}
    {% if comment_list %}
    <ul>
        {% for comment in comment_list %}
        {% if comment.is_public %}
        <li class="comment" id="c{{ comment.id }}">
            <header>
                <h1 class="name">
                {% if comment.user_url %}
                    <a href="{{ comment.user_url }}" title="{% trans "View" %} {% blocktrans with comment.user_name as user_name %}{{ user_name }}'s{% endblocktrans %} {% trans "website" %}">{{ comment.user_name }}</a>
                {% else %}
                    {{ comment.user_name }}
                {% endif %}
                {% trans "says" %}...
                </h1>
            </header>
            <div class="comment-content">
                {{ comment.comment|urlizetrunc:"60"|linebreaks }}
            </div>
            <footer>
                <p><a href="{{ comment.get_absolute_url }}" title="{% trans "Permalink to" %} {% blocktrans with comment.user_name as user_name %}{{ user_name }}'s{% endblocktrans %} {% trans "comment" %}">{% trans "Posted" %} <time class="comment-date" pubdate datetime="{{ comment.submit_date|date:"c" }}">{{ comment.submit_date|date }}</time></a></p>
            </footer>
        </li>
        {% endif %}
        {% endfor %}
    </ul>
    {% endif %}
    {% if object.allow_comments %}
    <h2>{% trans "Post a Comment" %}</h2>
    {% render_comment_form for object %}
    {% else %}
    <div id="comment_form">
    <h2>{% trans "Comments are closed" %}.</h2>
    <p>{% trans "Comments have been closed for this post" %}.</p>
    </div>
    {% endif %}
{% endif %}
</section>
