{% if forloop.counter %}
    {% if post.tease %}
        {{ post.tease_rendered|safe }}
        {% include 'vellum/includes/post_more.html' %}
    {% else %}
        {{ post.body_rendered|safe }}
    {% endif %}
{% else %}
    {{ post.body_rendered|safe }}
{% endif %}
