<p class="meta">This post was published{% if post.author %} by {{ post.author }}{% endif %} at <time pubdate datetime="{{ post.publish|date:"c" }}">{{ post.publish|date:"DATETIME_FORMAT" }}</time>{% if post.categories.all %} in {% for category in post.categories.all%}<a href="{% url vellum_category_detail slug=category.slug %}" title="View all posts in the {{ category }} category.">{{ category|lower }}</a>{% if not forloop.last %}, {% endif %}{% endfor %}{% endif %}. {% if post.tags.all %}It was tagged with {% for tag in post.tags.all %}<a href="{% url vellum_tag_detail slug=tag.slug %}" title="View all posts tagged with {{ tag }}.">{{ tag }}</a>{% if not forloop.last %}, {% endif %}{% endfor %}.{% endif %}</p>
