<!doctype html>
<html lang="en-us">
<head>
    <meta charset="utf-8">
    <title>{% block title %}{% endblock %}</title>
    <meta name="description" content="{% block description %}{% endblock %}">
    {% block extrahead %}{% endblock %}
</head>
<body id="{% block body_id %}{% endblock %}" class="{% block body_class %}{% endblock %}">
{% block body %}
    <header>
        <hgroup>
            <h1 id="site-title"><a href="/" title="{{ BLOG_NAME }}">{{ BLOG_NAME }}</a></h1>
            <h2 id="site-description">{{ BLOG_DESCRIPTION }}</h2>
        </hgroup>
    </header>

    <div id="content">
        {% block content %}{% endblock %}
    </div>
{% endblock %}
</body>
</html>
