{% extends "vellum/post_list.html" %}
{% load i18n %}

{% block title %}{{ tag }} | {{ block.super }}{% endblock %}
{% block description %}{% trans "Posts tagged with" %} {{ tag }}{% endblock %}
{% block body_class %}{{ block.super }} tag{% endblock %}
{% block body_id %}post-tag-{{ tag }}{% endblock %}
{% block page_notice %}<div class="notice"><p>
    {% if object_list %}
    {% trans "You are currently viewing all posts tagged with " %}
    {% else %}
    {% trans "No posts are tagged with " %}
    {% endif %}
     <span class="query">{{ tag }}</span>.
</p></div>{% endblock %}
