{% extends "vellum/post_list.html" %}
{% load i18n %}

{% block title %}{{ year }} | {{ block.super }}{% endblock %}
{% block description %}{{ object_list|length }} {% trans "posts published in the year" %} {{ year }}{% endblock %}
{% block body_class %}{{ block.super }} yearly{% endblock %}
{% block body_id %}post-archive-{{ year }}{% endblock %}
{% block page_title %}{% trans "Year" %}: {{ year }}{% endblock %}
