{% extends "vellum/base_vellum.html" %}
{% load i18n %}

{% block title %}{{ post.title }} | {{ block.super }}{% endblock %}
{% block description %}{{ post.excerpt|striptags|truncatewords:160 }}{% endblock %}
{% block body_class %}{{ block.super }} post-detail{% endblock %}
{% block body_id %}post-{{ post.id }}{% endblock %}

{% block content %}
    {% include 'vellum/includes/post.html' %}
    {% include 'vellum/includes/other_posts.html' %}
    {% include 'vellum/includes/comments.html' %}
{% endblock %}
