{% load i18n %}
<div class="pagination">
    {% if page_obj.has_next %}
    <a class="older" href="?page={{ page_obj.next_page_number }}" title="{% trans "View older posts." %}">&laquo; {% trans "Older" %}</a>
    {% endif %}
    {% if page_obj.has_previous %}<span class="separator">|</span>{% endif %}
    {% if page_obj.has_previous %}
    <a class="newer" href="?page={{ page_obj.previous_page_number }}" title="{% trans "View newer posts." %}">{% trans "Newer" %} &raquo;</a>
    {% endif %}
</div>
