{% extends "vellum/post_list.html" %}
{% load i18n %}

{% block title %}{{ day|date:"d" }} | {{ day|date:"F" }} | {{ day|date:"Y" }} | {{ block.super }}{% endblock %}
{% block description %}{{ object_list|length }} {% trans "posts published on" %} {{ day }}{% endblock %}
{% block body_class %}{{ block.super }} daily{% endblock %}
{% block body_id %}post-archive-{{ day|date:"Ymd" }}{% endblock %}
{% block page_title %}{% trans "Day" %}: {{ day }}{% endblock %}
