{% extends "vellum/base_vellum.html" %}

{% block body_id %}post-index{% endblock %}
{% block body_class %}{{ block.super }} archive post-list{% endblock %}

{% block content %}
    {% block page_notice %}{% endblock %}

    {% for post in object_list %}
        {% include 'vellum/includes/post.html' %}
    {% endfor %}

    {% if is_paginated %}
        {% include 'vellum/includes/pagination.html' %}
    {% endif %}
{% endblock %}
